@@ -12,11 +12,11 @@ Lugh - Pure C LLM Inference Engine for Perl (built on ggml)
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 require XSLoader;
 XSLoader::load('Lugh', $VERSION);
@@ -372,8 +372,21 @@ Available backends depend on your system and ggml installation:
 
 =item * C<metal_available()> - Check if Metal GPU is available at runtime
 
+=item * C<srand($seed)> - Seed the C random number generator used for sampling
+
 =back
 
+=head2 Reproducibility
+
+Sampling functions like C<sample_top_p> use C's random number generator. 
+To get reproducible results, seed it before sampling:
+
+    Lugh::srand(42);
+    my $token = $inference->sample_top_p(\@logits, temperature => 0.8);
+
+This is especially important for speculative decoding, where the draft model's
+sampling should be consistent regardless of prior operations.
+
 =head2 Memory Usage
 
 Memory depends on model size and quantization:
