@@ -12,11 +12,11 @@ Lugh::Inference - Transformer Forward Pass and Token Generation
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -752,10 +752,11 @@ B<Example:>
     # Positional form
     my $results = $inference->forward_batch(\@sequences);
     
-    # Named parameter form (required for LoRA)
+    # Named parameter form (required for LoRA or per-sequence caches)
     my $results = $inference->forward_batch(
         sequences => \@sequences,
         lora      => $lora,      # optional: Lugh::LoRA adapter
+        caches    => \@caches,   # optional: per-sequence KV caches
     );
 
 Processes multiple token sequences, returning logits for each.
@@ -769,6 +770,11 @@ B<Parameters:>
 
 =item * C<lora> (optional) - A Lugh::LoRA adapter to apply during inference
 
+=item * C<caches> (optional) - Array reference of KV caches, one per sequence.
+Must have the same count as sequences. Each sequence will use its corresponding
+cache for incremental decoding, allowing parallel continuation of multiple
+conversations.
+
 =back
 
 B<Returns:> Array reference of array references of logits.
@@ -797,6 +803,26 @@ B<Example:>
         sequences => [\@seq1, \@seq2, \@seq3],
         lora      => $lora,
     );
+    
+    # With per-sequence caches for incremental decoding
+    my $cache1 = $inference->create_kv_cache();
+    my $cache2 = $inference->create_kv_cache();
+    
+    # First pass - encode prompts
+    my $results = $inference->forward_batch(
+        sequences => [\@seq1, \@seq2],
+        caches    => [$cache1, $cache2],
+    );
+    
+    # Each cache now contains the KV state for its sequence
+    # Continue decoding with new tokens
+    my @next1 = ($inference->sample_top_p($results->[0], top_p => 0.9));
+    my @next2 = ($inference->sample_top_p($results->[1], top_p => 0.9));
+    
+    my $results2 = $inference->forward_batch(
+        sequences => [\@next1, \@next2],
+        caches    => [$cache1, $cache2],
+    );
 
 =head2 Convenience Methods
 
